

AsyncTAPJob
========================

.. currentmodule:: pyvo.dal.tap

.. autoclass:: AsyncTAPJob
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~AsyncTAPJob.destruction
      ~AsyncTAPJob.execution_duration
      ~AsyncTAPJob.job
      ~AsyncTAPJob.jobId
      ~AsyncTAPJob.owner
      ~AsyncTAPJob.phase
      ~AsyncTAPJob.quote
      ~AsyncTAPJob.result_uri
      ~AsyncTAPJob.result_uris
      ~AsyncTAPJob.url

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~AsyncTAPJob.abort
      ~AsyncTAPJob.create
      ~AsyncTAPJob.delete
      ~AsyncTAPJob.fetch_result
      ~AsyncTAPJob.raise_if_error
      ~AsyncTAPJob.run
      ~AsyncTAPJob.wait

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: destruction
   .. autoattribute:: execution_duration
   .. autoattribute:: job
   .. autoattribute:: jobId
   .. autoattribute:: owner
   .. autoattribute:: phase
   .. autoattribute:: quote
   .. autoattribute:: result_uri
   .. autoattribute:: result_uris
   .. autoattribute:: url

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: abort
   .. automethod:: create
   .. automethod:: delete
   .. automethod:: fetch_result
   .. automethod:: raise_if_error
   .. automethod:: run
   .. automethod:: wait

   
   